@@ -62,7 +62,14 @@ setGeneric("s_attributes", function(.Object, ...) standardGeneric("s_attributes"
 #' s_attributes("GERMAPARLMINI", "date") # dates of plenary meetings
 #' s_attributes("GERMAPARLMINI", s_attribute = c("date", "party"))  
 setMethod("s_attributes", "character", function(.Object, s_attribute = NULL, unique = TRUE, regex = NULL, ...){
-  if ("sAttribute" %in% names(list(...))) s_attribute <- list(...)[["sAttribute"]]
+  if ("sAttribute" %in% names(list(...))){
+    lifecycle::deprecate_warn(
+      when = "0.8.7", 
+      what = "s_attributes(sAttribute)",
+      with = "s_attributes(s_attribute)"
+    )
+    s_attribute <- list(...)[["sAttribute"]]
+  }
   s_attributes(.Object = corpus(.Object), s_attribute = s_attribute, unique = unique, regex = regex, ...)
 })
 
@@ -72,7 +79,14 @@ setMethod("s_attributes", "character", function(.Object, s_attribute = NULL, uni
 #' s_attributes(corpus("GERMAPARLMINI"))
 setMethod("s_attributes", "corpus", function(.Object, s_attribute = NULL, unique = TRUE, regex = NULL, ...){
   
-  if ("sAttribute" %in% names(list(...))) s_attribute <- list(...)[["sAttribute"]]
+  if ("sAttribute" %in% names(list(...))){
+    lifecycle::deprecate_warn(
+      when = "0.8.7", 
+      what = "s_attributes(sAttribute)",
+      with = "s_attributes(s_attribute)"
+    )
+    s_attribute <- list(...)[["sAttribute"]]
+  }
   
   if (is.null(s_attribute)){
     s_attrs <- corpus_s_attributes(
@@ -155,9 +169,18 @@ setMethod("s_attributes", "corpus", function(.Object, s_attribute = NULL, unique
 setMethod(
   "s_attributes", "slice",
   function (.Object, s_attribute = NULL, unique = TRUE, ...) {
-    if ("sAttribute" %in% names(list(...))) s_attribute <- list(...)[["sAttribute"]]
+    if ("sAttribute" %in% names(list(...))){
+      lifecycle::deprecate_warn(
+        when = "0.8.7", 
+        what = "s_attributes(sAttribute)",
+        with = "s_attributes(s_attribute)"
+      )
+      s_attribute <- list(...)[["sAttribute"]]
+    }
     if (is.null(s_attribute)){
-      return( registry_get_s_attributes(.Object@corpus) )
+      return(
+        corpus_s_attributes(.Object@corpus, registry = .Object@registry_dir)
+      )
     } else {
       if (length(s_attribute) == 1L){
         # Checking whether the xml is flat / whether s_attribute is in .Object@s_attribute_strucs 
@@ -263,13 +286,14 @@ setMethod("s_attributes", "partition_bundle", function(.Object, s_attribute, ...
 })
 
 
-#' @details If \code{.Object} is a call, the \code{s_attributes}-method will
-#'   return a character vector with the s-attributes occurring in the call. This
-#'   usage is relevant internally to implement the \code{subset} method to
-#'   generate a \code{subcorpus} using non-standard evaluation. Usually it will
-#'   not be relevant in an interactive session.
+#' @details If `.Object` is a `call` or a `quosure` (defined in the rlang
+#'   package), the `s_attributes`-method will return a `character` vector with
+#'   the s-attributes occurring in the call. This usage is relevant internally
+#'   to implement the `subset` method to generate a `subcorpus` using
+#'   non-standard evaluation. Usually it will not be relevant in an interactive
+#'   session.
 #' @rdname s_attributes-method
-#' @param corpus A \code{corpus}-object or a length one character vector
+#' @param corpus A `corpus`-object or a length one character vector
 #'   denoting a corpus.
 #' @examples
 #' 
@@ -281,6 +305,12 @@ setMethod("s_attributes", "partition_bundle", function(.Object, s_attribute, ...
 #'   quote(speaker == "Angela Merkel" & date == "2009-10-28"),
 #'   corpus = "GERMAPARLMINI"
 #' )
+#' 
+#' # Get s-attributes from quosure
+#' s_attributes(
+#'   rlang::new_quosure(quote(grep("Merkel", speaker))),
+#'   corpus = "GERMAPARLMINI"
+#' )
 #' @importFrom RcppCWB corpus_s_attributes
 setMethod("s_attributes", "call", function(.Object, corpus){
   s_attrs <- s_attributes(corpus)
@@ -292,7 +322,8 @@ setMethod("s_attributes", "call", function(.Object, corpus){
       registry = corpus@registry_dir
     )
   }
-  # for the following recursive function, see http://adv-r.had.co.nz/Expressions.html
+  # for the following recursive function,
+  # see http://adv-r.had.co.nz/Expressions.html
   .fn <- function(x){
     if (is.call(x)){
       y <- lapply(x, .fn)
@@ -304,7 +335,7 @@ setMethod("s_attributes", "call", function(.Object, corpus){
         if (!exists(char)){
           warning(
             sprintf(
-              "expression includes undefined symbol that does not refer to s-attribute: %s",
+              "expression includes undefined symbol that is not a s-attribute: %s",
               char
             )
           )
@@ -320,6 +351,13 @@ setMethod("s_attributes", "call", function(.Object, corpus){
 })
 
 
+#' @rdname s_attributes-method
+#' @importFrom rlang quo_get_expr
+setMethod("s_attributes", "quosure", function(.Object, corpus){
+  s_attributes(quo_get_expr(.Object), corpus = corpus)
+})
+
+
 #' @rdname s_attributes-method
 setMethod("s_attributes", "remote_corpus", function(.Object, ...){
   ocpu_exec(fn = "s_attributes", corpus = .Object@corpus, server = .Object@server, restricted = .Object@restricted, .Object = as(.Object, "corpus"), ...)
