@@ -22,8 +22,8 @@ setMethod("view", "cooccurrences", function(.Object){
 #' @rdname kwic-class
 #' @param .Object A \code{kwic} class object.
 setMethod("view", "kwic", function(.Object){
-  tableToView <- .Object@table
-  get("View", envir = .GlobalEnv)(tableToView)
+  table_to_view <- .Object@stat
+  get("View", envir = .GlobalEnv)(table_to_view)
 })
 
 #' @rdname textstat-class
@@ -41,8 +41,18 @@ setMethod("view", "features", function(.Object){
 })
 
 #' @rdname cooccurrences-class
-setMethod(view, "cooccurrences_reshaped", function(.Object){
+setMethod("view", "cooccurrences_reshaped", function(.Object){
   .Object <- round(.Object, digits = 2)
   colsToView <- c("a", "b", "count_ab", "count_a", "count_b", "ll_a2b", "ll_b2a")
   get("View", envir = .GlobalEnv)(.Object@stat[, colsToView, with = FALSE])
 })
+
+setMethod("view", "kwic", function(.Object){
+  warning(
+    "Using the 'view()'-method to inspect an object of the 'kwic'-class works, ",
+    "but the default method for kwic results is the 'show()'-method. ",
+    "You may see the column 'match_id', which is used internally, and raw html ",
+    "to highlight terms in the context of query matches."
+  )
+  callNextMethod()
+})
