@@ -1,6 +1,7 @@
 library(polmineR)
 testthat::context("decode")
 use("polmineR")
+use(pkg = "RcppCWB", corpus = "REUTERS")
 
 
 test_that(
@@ -11,9 +12,9 @@ test_that(
 
 test_that(
   "size of corpus, split by one s-attribute", {
-    y <- size("GERMAPARLMINI", sAttribute = "date")
+    y <- size("GERMAPARLMINI", s_attribute = "date")
     expect_equal(sum(y[["size"]]), size("GERMAPARLMINI"))
-    expect_equal(nrow(y), length(sAttributes("GERMAPARLMINI", "date")))
+    expect_equal(nrow(y), length(s_attributes("GERMAPARLMINI", "date")))
     expect_equal(y[["size"]][1:3], c(9341, 2793, 68316))
     
     y <- corpus("GERMAPARLMINI") %>% size(s_attribute = "date")
@@ -27,7 +28,7 @@ test_that(
   "size of corpus, two s-attributes", {
     
     # corpus stated by ID
-    y <- size("GERMAPARLMINI", sAttribute = c("date", "party"))
+    y <- size("GERMAPARLMINI", s_attribute = c("date", "party"))
     expect_equal(length(unique(y[["party"]])), 6)
     expect_equal(sum(y[["size"]]), size("GERMAPARLMINI"))
     expect_equal(y[["size"]][1:3], c(17,71,25))
@@ -37,15 +38,26 @@ test_that(
     expect_equal(length(unique(y[["party"]])), 6)
     expect_equal(sum(y[["size"]]), size("GERMAPARLMINI"))
     expect_equal(y[["size"]][1:3], c(17,71,25))
+
   }
 )
 
 test_that(
-  "size of partition", {
+  "size of partition / subcorpus",
+  {
     P <- partition("GERMAPARLMINI", date = "2009-11-11")
     expect_equal(size(P), 117614)
-    expect_equal(sum(size(P, sAttribute = "speaker")[["size"]]), size(P))
-    expect_equal(sum(size(P, sAttribute = c("speaker", "party"))[["size"]]), size(P))
+    expect_equal(sum(size(P, s_attribute = "speaker")[["size"]]), size(P))
+    expect_equal(sum(size(P, s_attribute = c("speaker", "party"))[["size"]]), size(P))
+    
+    coi <- corpus("GERMAPARLMINI") %>%
+      subset(grepl("2009-11-.*", protocol_date))
+    
+    s <- size(coi, s_attribute = "speaker", verbose = FALSE)
+    a <- size(coi, s_attribute = c("speaker", "date"), verbose = FALSE)
+    b <- size(coi, s_attribute = c("speaker", "protocol_date"), verbose = FALSE)
+    expect_identical(sum(a$size), sum(b$size))
+    # expect_identical(sum(a$size), size("GERMAPARLMINI"))
   }
 )
 
